@@ -12,7 +12,7 @@ use warnings;
 
 package Dist::Zilla::PluginBundle::Author::JQUELIN;
 # ABSTRACT: Build & release a distribution like jquelin
-$Dist::Zilla::PluginBundle::Author::JQUELIN::VERSION = '3.003';
+$Dist::Zilla::PluginBundle::Author::JQUELIN::VERSION = '3.004';
 use Class::MOP;
 use Moose;
 use Moose::Autobox;
@@ -50,11 +50,11 @@ use Dist::Zilla::Plugin::PruneCruft;
 use Dist::Zilla::Plugin::PruneFiles;
 use Dist::Zilla::Plugin::Readme;
 use Dist::Zilla::Plugin::ReadmeMarkdownFromPod;
-use Dist::Zilla::Plugin::ReportVersions::Tiny;
 use Dist::Zilla::Plugin::Repository;
 use Dist::Zilla::Plugin::ShareDir;
 use Dist::Zilla::Plugin::TaskWeaver;
 use Dist::Zilla::Plugin::Test::Compile 1.100220;
+use Dist::Zilla::Plugin::Test::ReportPrereqs;
 use Dist::Zilla::Plugin::TestRelease;
 use Dist::Zilla::Plugin::UploadToCPAN;
 
@@ -77,11 +77,11 @@ sub bundle_config {
         [ 'Git::NextVersion' => {} ],
 
         # -- fetch & generate files
-        [ GatherDir              => {} ],
-        [ 'Test::Compile'        => {} ],
-        [ PodCoverageTests       => {} ],
-        [ PodSyntaxTests         => {} ],
-        [ 'ReportVersions::Tiny' => {} ],
+        [ GatherDir             => {} ],
+        [ 'Test::Compile'       => {} ],
+        [ PodCoverageTests      => {} ],
+        [ PodSyntaxTests        => {} ],
+        [ 'Test::ReportPrereqs' => {} ],
 
         # -- remove some files
         [ PruneCruft   => {} ],
@@ -163,7 +163,7 @@ Dist::Zilla::PluginBundle::Author::JQUELIN - Build & release a distribution like
 
 =head1 VERSION
 
-version 3.003
+version 3.004
 
 =head1 SYNOPSIS
 
